<?php
if (!defined('ABSPATH')) {
    exit;
}

// Add Settings Submenu (already exists, keep it)
function scv_add_settings_submenu() {
    add_submenu_page(
        'edit.php?post_type=student_certificate',
        'Certificate Settings',
        'Settings',
        'manage_options',
        'scv-settings',
        'scv_settings_page_callback'
    );
}
add_action('admin_menu', 'scv_add_settings_submenu');

// Add Bulk Upload Submenu (already exists, keep it)
function scv_add_bulk_upload_submenu() {
    add_submenu_page(
        'edit.php?post_type=student_certificate',
        'Bulk Upload Students',
        'Bulk Upload',
        'manage_options',
        'scv-bulk-upload',
        'scv_bulk_upload_page_callback'
    );
}
add_action('admin_menu', 'scv_add_bulk_upload_submenu');

// Add Certificate Customization Submenu (already exists, keep it)
function scv_add_customization_submenu() {
    add_submenu_page(
        'edit.php?post_type=student_certificate',
        'Certificate Customization',
        'Customization',
        'manage_options',
        'scv-customization',
        'scv_customization_page_callback'
    );
}
add_action('admin_menu', 'scv_add_customization_submenu');

// Updated Settings Page Callback
function scv_settings_page_callback() {
    if (isset($_POST['scv_license_key'])) {
        $key = sanitize_text_field($_POST['scv_license_key']);
        update_option('scv_license_key', $key);
        scv_check_license(); // Validate immediately
        add_settings_error('scv_messages', 'license_updated', 'License Key Updated!', 'success');
    }

    $license_key = get_option('scv_license_key', '');
    $is_pro = scv_check_license();
    ?>
    <div class="wrap">
        <h1>Certificate Plugin Settings</h1>
        <?php settings_errors('scv_messages'); ?>
        <style>
            .custom-button-container { display: flex; gap: 15px; margin-top: 20px; }
            .custom-button { padding: 12px 20px; font-size: 16px; font-weight: bold; text-align: center; text-decoration: none; border-radius: 8px; transition: all 0.3s ease; border: none; cursor: pointer; }
            .btn-demo { background: linear-gradient(135deg, #4CAF50, #2E7D32); color: white; box-shadow: 0 4px 6px rgba(0, 0, 0, 0.2); }
            .btn-demo:hover { background: linear-gradient(135deg, #45a049, #1B5E20); transform: translateY(-2px); color: white; box-shadow: 0 6px 12px rgba(0, 0, 0, 0.3); }
            .btn-how-to { background: linear-gradient(135deg, #2196F3, #0D47A1); color: white; box-shadow: 0 4px 6px rgba(0, 0, 0, 0.2); }
            .btn-how-to:hover { background: linear-gradient(135deg, #1E88E5, #0B3D91); transform: translateY(-2px); color: white; box-shadow: 0 6px 12px rgba(0, 0, 0, 0.3); }
        </style>
        <div class="custom-button-container">
            <a href="https://www.youtube.com/watch?v=YOUR_VIDEO_ID_1" target="_blank" class="custom-button btn-demo">🎥 Plugin Preview Demo</a>
            <a href="https://www.youtube.com/watch?v=YOUR_VIDEO_ID_2" target="_blank" class="custom-button btn-how-to">📖 How to Use</a>
        </div>
        <div class="settings-sections">
            <div class="info-group">
                <div class="how-to-use-container">
                    <h2>📖 How to Use</h2>
                    <p><strong>Here it is:</strong> Copy the following shortcode and paste it where you want to add:</p>
                    <div class="shortcode-box">
                        <pre id="shortcode-text">[verify_certificate]</pre>
                        <button class="copy-button" onclick="copyShortcode()">📋 Copy</button>
                    </div>
                    <p><strong>Additional Notes:</strong></p>
                    <ul class="how-to-list">
                        <li>✅ When you add Student's Details, this plugin will **automatically generate a certificate in PDF** that students can download.</li>
                        <li>📂 You can also **upload a PDF certificate manually** in your media, copy the PDF link, and paste it in **PDF Download Link (URL)** while adding student details.</li>
                    </ul>
                </div>
                <style>
                    .how-to-use-container { margin-top: 30px; padding: 20px; background: #e9f5ff; border-left: 5px solid #0073aa; border-radius: 8px; box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1); transition: all 0.3s ease; }
                    .how-to-use-container:hover { box-shadow: 0 6px 14px rgba(0, 0, 0, 0.15); transform: translateY(-2px); }
                    .shortcode-box { display: flex; align-items: center; background: #f4f4f4; padding: 10px; border-radius: 8px; font-family: monospace; }
                    #shortcode-text { margin: 0; font-size: 14px; color: #333; }
                    .copy-button { background: #0073aa; color: white; border: none; padding: 6px 12px; margin-left: 10px; border-radius: 5px; cursor: pointer; transition: background 0.3s ease; }
                    .copy-button:hover { background: #005a87; }
                    .how-to-list { list-style: none; padding-left: 0; }
                    .how-to-list li { margin: 8px 0; padding-left: 25px; position: relative; font-size: 15px; }
                    .how-to-list li::before { content: "✔"; position: absolute; left: 0; top: 2px; color: #0073aa; font-weight: bold; }
                </style>
                <script>
                    function copyShortcode() {
                        var shortcodeText = document.getElementById("shortcode-text").innerText;
                        navigator.clipboard.writeText(shortcodeText).then(function() {
                            alert("Shortcode copied: " + shortcodeText);
                        }).catch(function(err) {
                            console.error("Failed to copy: ", err);
                        });
                    }
                </script>
                <div class="free-version-notice">
                    <p><strong>⚠ Note:</strong> In our Free version, you can add only <strong>5 students</strong>. You have to enter a valid Pro License Key to add unlimited students.</p>
                    <p><a href="https://creativedeep.net/student-certificate-verification-wordpress-plugin/" target="_blank" class="buy-license-button">🔗 Visit Us to Buy License</a></p>
                </div>
                <style>
                    .free-version-notice { background: linear-gradient(135deg, #fff3cd, #ffeb9c); border-left: 5px solid #ffc107; padding: 15px; margin-bottom: 20px; border-radius: 8px; box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1); transition: all 0.3s ease-in-out; }
                    .free-version-notice:hover { box-shadow: 0 6px 14px rgba(0, 0, 0, 0.15); transform: translateY(-2px); }
                    .free-version-notice p { font-size: 16px; color: #664d03; margin-bottom: 10px; }
                    .buy-license-button { display: inline-block; background: #ff9800; color: #fff; padding: 10px 16px; border-radius: 6px; text-decoration: none; font-weight: bold; transition: all 0.3s ease; box-shadow: 0 3px 6px rgba(0, 0, 0, 0.15); }
                    .buy-license-button:hover { background: #e68900; transform: scale(1.05); }
                </style>
            </div>
            <div class="license-group">
                <form method="post" class="license-form">
                    <h2>🔑 Enter License Key</h2>
                    <p>Enter your Pro License Key below to unlock unlimited student records.</p>
                    <input type="password" id="scv_license_key" name="scv_license_key" value="<?php echo esc_attr($license_key); ?>" class="license-input" placeholder="Enter License Key">
                    <button type="submit" class="save-license-button">✅ Save License</button>
                </form>
                <style>
                    .license-form { background: #ffffff; padding: 20px; border-radius: 8px; box-shadow: 0px 4px 12px rgba(0, 0, 0, 0.1); border: 1px solid #ddd; max-width: 400px; margin-top: 20px; }
                    .license-form h2 { font-size: 18px; color: #0073aa; margin-bottom: 8px; }
                    .license-form p { font-size: 14px; color: #333; margin-bottom: 12px; }
                    .license-input { width: 100%; padding: 10px; border-radius: 5px; border: 1px solid #ccc; font-size: 16px; transition: 0.3s ease-in-out; background: #f8f9fa; }
                    .license-input:focus { border-color: #0073aa; box-shadow: 0px 0px 6px rgba(0, 115, 170, 0.3); outline: none; background: #fff; }
                    .save-license-button { display: block; background: #0073aa; color: #fff; padding: 12px; border-radius: 5px; text-align: center; font-weight: bold; transition: 0.3s; width: 100%; border: none; cursor: pointer; font-size: 16px; margin-top: 10px; }
                    .save-license-button:hover { background: #005a87; transform: scale(1.02); }
                </style>
                <div class="license-status <?php echo $is_pro ? 'pro' : 'free'; ?>">
                    <h2>🔍 License Status</h2>
                    <p>
                        <?php if (!$is_pro) : ?>
                            ❌ You are using the <strong>Free version</strong> (Limited to 5 students).
                        <?php else : ?>
                            ✅ <strong>Pro Version Activated!</strong> You can now add unlimited student records.
                        <?php endif; ?>
                    </p>
                </div>
            </div>
        </div>
        <style>
            .settings-sections { display: flex; flex-direction: column; gap: 20px; margin-top: 20px; }
            .info-group, .license-group { display: flex; flex-direction: row; gap: 20px; background-color: #f9f9f9; padding: 20px; border-radius: 8px; box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1); }
            .how-to-use-container, .free-version-notice, .license-form, .license-status { flex: 1; margin-top: 0; margin-bottom: 0; }
            .license-status { padding: 15px; border-radius: 5px; }
            .license-status.free { background: #f8d7da; }
            .license-status.pro { background: #d4edda; }
        </style>
    </div>
    <?php
}

// Keep other functions (scv_bulk_upload_page_callback, scv_customization_page_callback) below as they were