<?php
if (!defined('ABSPATH')) {
    exit;
}

function scv_bulk_upload_page_callback() {
    ?>
    <div class="wrap scv-bulk-upload-wrap">
        <h1 class="scv-bulk-title"><?php _e('Bulk Upload Students', 'student-certificate-verification'); ?></h1>
        <p class="scv-bulk-desc"><?php _e('Upload a CSV with: <strong>Student Name, Gender, Father Name, Course Name, Percentage, Year of Passing, Academy Name</strong>. Certificate numbers are auto-generated.', 'student-certificate-verification'); ?></p>
        <div class="scv-sample-container">
            <p><a href="<?php echo esc_url(admin_url('admin-post.php?action=scv_download_sample_csv')); ?>" class="scv-sample-link"><?php _e('Download Sample CSV', 'student-certificate-verification'); ?></a></p>
            <p><a href="<?php echo esc_url(admin_url('admin-post.php?action=scv_export_students')); ?>" class="scv-sample-link" style="background: #0073aa;"><?php _e('Export Students', 'student-certificate-verification'); ?></a></p>
        </div>

        <?php
        if (isset($_POST['scv_bulk_upload_nonce']) && wp_verify_nonce($_POST['scv_bulk_upload_nonce'], 'scv_bulk_upload_action')) {
            if (isset($_FILES['scv_csv_file']) && $_FILES['scv_csv_file']['error'] === UPLOAD_ERR_OK) {
                $license_key = get_option('scv_license_key', '');
                $is_pro = !empty($license_key);
                $student_count = wp_count_posts('student_certificate')->publish;

                if (!$is_pro && $student_count >= 5) {
                    echo '<div class="error scv-error-notice"><p>' . esc_html__('❌ Free version limit reached (5 students). Upgrade to Pro.', 'student-certificate-verification') . '</p></div>';
                } else {
                    $file = $_FILES['scv_csv_file']['tmp_name'];
                    if (($handle = fopen($file, 'r')) !== false) {
                        $headers = fgetcsv($handle);
                        $expected_headers = array('Student Name', 'Gender', 'Father Name', 'Course Name', 'Percentage', 'Year of Passing', 'Academy Name');
                        $normalized_headers = array_map(function($header) {
                            return strtolower(trim($header));
                        }, $headers);
                        $normalized_expected = array_map('strtolower', $expected_headers);

                        if ($normalized_headers === $normalized_expected) {
                            $success_count = 0;
                            $row = 2;
                            while (($data = fgetcsv($handle)) !== false) {
                                if (count($data) !== 7) { // Updated to expect 7 columns
                                    echo '<div class="error scv-error-notice"><p>' . esc_html(sprintf(__('❌ Row %d skipped: Incorrect columns (expected 7).', 'student-certificate-verification'), $row)) . '</p></div>';
                                    $row++;
                                    continue;
                                }
                                scv_process_row($data, $is_pro, $student_count, $success_count);
                                $row++;
                            }
                            if ($success_count > 0) {
                                echo '<div class="updated scv-success-notice"><p>' . esc_html(sprintf(__('✅ Added %d students successfully!', 'student-certificate-verification'), $success_count)) . '</p></div>';
                            }
                        } else {
                            $header_diff = implode(', ', $headers);
                            error_log("CSV Headers Received: $header_diff");
                            error_log("Expected Headers: " . implode(', ', $expected_headers));
                            echo '<div class="error scv-error-notice"><p>' . esc_html__('❌ Wrong CSV format. Expected: ' . implode(', ', $expected_headers) . '. Received: ' . $header_diff) . '</p></div>';
                        }
                        fclose($handle);
                    }
                }
            } else {
                echo '<div class="error scv-error-notice"><p>' . esc_html__('❌ File upload error.', 'student-certificate-verification') . '</p></div>';
            }
        }
        ?>
        <form method="post" enctype="multipart/form-data" class="scv-bulk-form">
            <?php wp_nonce_field('scv_bulk_upload_action', 'scv_bulk_upload_nonce'); ?>
            <p><input type="file" name="scv_csv_file" accept=".csv" required class="scv-file-input"></p>
            <p><input type="submit" value="<?php esc_attr_e('Upload CSV', 'student-certificate-verification'); ?>" class="button button-primary scv-submit-btn"></p>
        </form>
    </div>
    <?php
}

function scv_process_row($data, $is_pro, &$student_count, &$success_count) {
    if (!$is_pro && $student_count >= 5) {
        echo '<div class="error scv-error-notice"><p>' . esc_html__('❌ Stopped: Free version limit reached (5 students).', 'student-certificate-verification') . '</p></div>';
        return;
    }

    $student_name = sanitize_text_field($data[0]);
    $gender = sanitize_text_field($data[1]);
    $father_name = sanitize_text_field($data[2]);
    $course_name = sanitize_text_field($data[3]);
    $percentage = floatval($data[4]); // Shifted indices due to removal of Certificate Number
    $year_of_passing = intval($data[5]);
    $academy_name = sanitize_text_field($data[6]);

    if (empty($student_name)) return;

    if (!in_array($gender, array('Male', 'Female'))) $gender = '';
    if ($percentage < 0 || $percentage > 100) $percentage = '';
    if ($year_of_passing < 1900 || $year_of_passing > date('Y')) $year_of_passing = '';

    $post_id = wp_insert_post(array(
        'post_title' => $student_name,
        'post_type' => 'student_certificate',
        'post_status' => 'publish',
    ));

    if ($post_id && !is_wp_error($post_id)) {
        $_POST = array(
            'scv_student_nonce' => wp_create_nonce('scv_student_meta_save'),
            'gender' => $gender,
            'father_name' => $father_name,
            'course_name' => $course_name,
            'percentage' => $percentage,
            'year_of_passing' => $year_of_passing,
            'academy_name' => $academy_name,
            'post_status' => 'publish',
        );
        scv_save_student_details($post_id); // Certificate number is generated here
        $success_count++;
        $student_count = wp_count_posts('student_certificate')->publish;
    }
}

function scv_export_students() {
    if (!current_user_can('manage_options')) wp_die('No permission.');
    $args = array('post_type' => 'student_certificate', 'posts_per_page' => -1, 'post_status' => 'publish');
    $students = get_posts($args);
    header('Content-Type: text/csv; charset=utf-8');
    header('Content-Disposition: attachment; filename="students_export_' . date('Y-m-d_H-i-s') . '.csv"');
    $output = fopen('php://output', 'w');
    fputcsv($output, array('Student Name', 'Gender', 'Father Name', 'Course Name', 'Percentage', 'Year of Passing', 'Academy Name')); // Removed Certificate Number
    foreach ($students as $student) {
        fputcsv($output, array(
            get_the_title($student->ID),
            get_post_meta($student->ID, 'gender', true) ?: '',
            get_post_meta($student->ID, 'father_name', true) ?: '',
            get_post_meta($student->ID, 'course_name', true) ?: '',
            get_post_meta($student->ID, 'percentage', true) ?: '',
            get_post_meta($student->ID, 'year_of_passing', true) ?: '',
            get_post_meta($student->ID, 'academy_name', true) ?: '',
        ));
    }
    fclose($output);
    exit;
}
add_action('admin_post_scv_export_students', 'scv_export_students');

function scv_download_sample_csv() {
    if (!current_user_can('manage_options')) wp_die('No permission.');
    header('Content-Type: text/csv; charset=utf-8');
    header('Content-Disposition: attachment; filename="sample-students.csv"');
    $output = fopen('php://output', 'w');
    fputcsv($output, array('Student Name', 'Gender', 'Father Name', 'Course Name', 'Percentage', 'Year of Passing', 'Academy Name'));
    fputcsv($output, array('John Doe', 'Male', 'James Doe', 'Web Development', '85', '2023', 'Creative Deep Academy'));
    fputcsv($output, array('Jane Smith', 'Female', 'Robert Smith', 'Graphic Design', '92', '2024', 'Creative Deep Academy'));
    fclose($output);
    exit;
}
add_action('admin_post_scv_download_sample_csv', 'scv_download_sample_csv');
?>