<?php
if (!defined('ABSPATH')) {
    exit;
}

function scv_customization_page_callback() {
    if (isset($_POST['scv_customization_nonce']) && wp_verify_nonce($_POST['scv_customization_nonce'], 'scv_customization_action')) {
        $fields = array(
            'reg_prefix' => 'sanitize_text_field',
            'academy_name' => 'sanitize_text_field',
            'academy_size' => 'intval',
            'academy_color' => 'sanitize_hex_color_no_hash',
            'certification_line1' => 'sanitize_text_field',
            'certification_line1_color' => 'sanitize_hex_color_no_hash',
            'certification_line2' => 'sanitize_text_field',
            'certification_line2_color' => 'sanitize_hex_color_no_hash',
            'certificate_title' => 'sanitize_text_field',
            'title_size' => 'intval',
            'title_color' => 'sanitize_hex_color_no_hash',
            'certification_text' => 'sanitize_text_field',
            'certification_size' => 'intval',
            'certification_color' => 'sanitize_hex_color_no_hash',
            'additional_info' => 'sanitize_text_field',
            'additional_info_color' => 'sanitize_hex_color_no_hash',
            'font_choice' => 'sanitize_text_field',
            'background_template' => 'sanitize_text_field',
        );
        foreach ($fields as $key => $sanitize_func) {
            if (isset($_POST[$key])) {
                $value = call_user_func($sanitize_func, $_POST[$key]);
                if (in_array($key, array('academy_size', 'title_size', 'certification_size')) && ($value < 8 || $value > 50)) {
                    $value = ($key === 'certification_size') ? 12 : 20;
                }
                if ($key === 'font_choice' && !in_array($value, array('Arial', 'Times', 'Helvetica'))) {
                    $value = 'Arial';
                }
                if ($key === 'background_template') {
                    $available_templates = scv_get_background_templates();
                    if (!array_key_exists($value, $available_templates)) {
                        $value = scv_get_default_background_template();
                    }
                }
                update_option("scv_$key", $value);
            }
        }
        $upload_types = array('logo', 'signature', 'seal');
        foreach ($upload_types as $type) {
            if (!empty($_FILES["scv_$type"]['name'])) {
                $upload_overrides = array('test_form' => false, 'mimes' => array('png' => 'image/png', 'jpg|jpeg' => 'image/jpeg'));
                $upload = wp_handle_upload($_FILES["scv_$type"], $upload_overrides);
                if (isset($upload['file']) && !isset($upload['error'])) {
                    update_option("scv_{$type}_path", $upload['file']);
                    update_option("scv_{$type}_url", $upload['url']);
                } else {
                    add_settings_error('scv_messages', "{$type}_error", ucfirst($type) . ' upload failed: ' . $upload['error'], 'error');
                }
            }
            if (isset($_POST["scv_delete_$type"]) && $_POST["scv_delete_$type"] === '1') {
                $path = get_option("scv_{$type}_path");
                if ($path && file_exists($path)) {
                    unlink($path);
                }
                update_option("scv_{$type}_path", '');
                update_option("scv_{$type}_url", '');
                add_settings_error('scv_messages', "{$type}_deleted", ucfirst($type) . ' deleted successfully!', 'success');
            }
        }
        wp_cache_delete('scv_customization_settings'); // Clear cache after save
        add_settings_error('scv_messages', 'customization_success', 'Customization settings saved successfully!', 'success');
    }

    $settings = scv_get_customization_settings();
    $templates = scv_get_background_templates();
    ?>
    <div class="wrap scv-customization-wrap">
        <h1 class="scv-custom-title">Certificate Customization</h1>
        <p class="scv-custom-desc">Customize the content and images on your PDF certificates. Use placeholders like [student_name], [father_name], etc., in the Certification Text field.</p>
        <form method="post" enctype="multipart/form-data">
            <?php wp_nonce_field('scv_customization_action', 'scv_customization_nonce'); ?>
            <?php settings_errors('scv_messages'); ?>
            <h2 class="scv-section-title">Text Customization</h2>
            <table class="form-table scv-customization-table scv-text-custom-table">
                <tr>
                    <th><label for="reg_prefix">Registration Prefix</label></th>
                    <td>
                        <input type="text" name="reg_prefix" id="reg_prefix" value="<?php echo esc_attr($settings['reg_prefix']); ?>" class="regular-text scv-input">
                        <p>Size: <input type="number" name="academy_size" value="<?php echo esc_attr($settings['academy_size']); ?>" min="8" max="50" class="scv-number-input"> px</p>
                        <p>Color: <input type="color" name="academy_color" value="#<?php echo esc_attr($settings['academy_color']); ?>" class="scv-color-input"></p>
                    </td>
                </tr>
                <tr><td colspan="2"><hr class="scv-divider"></td></tr>
                <tr>
                    <th><label for="academy_name">Academy Name (Header)</label></th>
                    <td>
                        <input type="text" name="academy_name" id="academy_name" value="<?php echo esc_attr($settings['academy_name']); ?>" class="regular-text scv-input">
                        <p>Size: <input type="number" name="academy_size" value="<?php echo esc_attr($settings['academy_size']); ?>" min="8" max="50" class="scv-number-input"> px</p>
                        <p>Color: <input type="color" name="academy_color" value="#<?php echo esc_attr($settings['academy_color']); ?>" class="scv-color-input"></p>
                    </td>
                </tr>
                <tr><td colspan="2"><hr class="scv-divider"></td></tr>
                <tr>
                    <th><label for="certification_line1">Certification Line 1</label></th>
                    <td>
                        <input type="text" name="certification_line1" id="certification_line1" value="<?php echo esc_attr($settings['certification_line1']); ?>" class="regular-text scv-input">
                        <p>Size: <input type="number" name="academy_size" value="<?php echo esc_attr($settings['academy_size']); ?>" min="8" max="50" class="scv-number-input"> px</p>
                        <p>Color: <input type="color" name="certification_line1_color" value="#<?php echo esc_attr($settings['certification_line1_color']); ?>" class="scv-color-input"></p>
                    </td>
                </tr>
                <tr><td colspan="2"><hr class="scv-divider"></td></tr>
                <tr>
                    <th><label for="certification_line2">Certification Line 2</label></th>
                    <td>
                        <input type="text" name="certification_line2" id="certification_line2" value="<?php echo esc_attr($settings['certification_line2']); ?>" class="regular-text scv-input">
                        <p>Size: <input type="number" name="academy_size" value="<?php echo esc_attr($settings['academy_size']); ?>" min="8" max="50" class="scv-number-input"> px</p>
                        <p>Color: <input type="color" name="certification_line2_color" value="#<?php echo esc_attr($settings['certification_line2_color']); ?>" class="scv-color-input"></p>
                    </td>
                </tr>
                <tr><td colspan="2"><hr class="scv-divider"></td></tr>
                <tr>
                    <th><label for="certificate_title">Certificate Title</label></th>
                    <td>
                        <input type="text" name="certificate_title" id="certificate_title" value="<?php echo esc_attr($settings['certificate_title']); ?>" class="regular-text scv-input">
                        <p>Size: <input type="number" name="title_size" value="<?php echo esc_attr($settings['title_size']); ?>" min="8" max="50" class="scv-number-input"> px</p>
                        <p>Color: <input type="color" name="title_color" value="#<?php echo esc_attr($settings['title_color']); ?>" class="scv-color-input"></p>
                    </td>
                </tr>
                <tr><td colspan="2"><hr class="scv-divider"></td></tr>
                <tr>
                    <th><label for="certification_text">Certification Text</label></th>
                    <td>
                        <textarea name="certification_text" id="certification_text" rows="5" class="large-text scv-textarea"><?php echo esc_textarea($settings['certification_text']); ?></textarea>
                        <p>Size: <input type="number" name="certification_size" value="<?php echo esc_attr($settings['certification_size']); ?>" min="8" max="50" class="scv-number-input"> px</p>
                        <p>Color: <input type="color" name="certification_color" value="#<?php echo esc_attr($settings['certification_color']); ?>" class="scv-color-input"></p>
                    </td>
                </tr>
                <tr><td colspan="2"><hr class="scv-divider"></td></tr>
                <tr>
                    <th><label for="additional_info">Additional Info (Footer)</label></th>
                    <td>
                        <input type="text" name="additional_info" id="additional_info" value="<?php echo esc_attr($settings['additional_info']); ?>" class="regular-text scv-input">
                        <p>Size: <input type="number" name="academy_size" value="<?php echo esc_attr($settings['academy_size']); ?>" min="8" max="50" class="scv-number-input"> px</p>
                        <p>Color: <input type="color" name="additional_info_color" value="#<?php echo esc_attr($settings['additional_info_color']); ?>" class="scv-color-input"></p>
                    </td>
                </tr>
                <tr><td colspan="2"><hr class="scv-divider"></td></tr>
                <tr>
                    <th><label for="font_choice">Font Choice</label></th>
                    <td>
                        <select name="font_choice" id="font_choice" class="scv-select">
                            <option value="Arial" <?php selected($settings['font_choice'], 'Arial'); ?>>Arial</option>
                            <option value="Times" <?php selected($settings['font_choice'], 'Times'); ?>>Times</option>
                            <option value="Helvetica" <?php selected($settings['font_choice'], 'Helvetica'); ?>>Helvetica</option>
                        </select>
                    </td>
                </tr>
            </table>
            <h2 class="scv-section-title">Image Customization</h2>
            <table class="form-table scv-customization-table">
                <tr>
                    <th><label>Background Template</label></th>
                    <td>
                        <input type="hidden" name="background_template" id="scv_background_template" value="<?php echo esc_attr($settings['background_template']); ?>">
                        <div class="scv-template-cards">
                            <?php
                            foreach ($templates as $value => $label) {
                                $is_selected = ($settings['background_template'] === $value) ? ' selected' : '';
                                echo '<div class="scv-template-card' . $is_selected . '" data-template="' . esc_attr($value) . '">';
                                echo '<img src="' . plugin_dir_url(__FILE__) . '../../images/' . esc_attr($value) . '" alt="' . esc_attr($label) . '">';
                                echo '<p>' . esc_html($label) . '</p>';
                                echo '</div>';
                            }
                            ?>
                        </div>
                        <p>Preview: <img id="background_preview" src="<?php echo plugin_dir_url(__FILE__) . '../../images/' . esc_attr($settings['background_template']); ?>" class="scv-preview-img"></p>
                    </td>
                </tr>
                <tr>
                    <th><label for="scv_logo">Logo Upload</label></th>
                    <td>
                        <input type="file" name="scv_logo" id="scv_logo" accept="image/png,image/jpeg" class="scv-file-input">
                        <?php if ($settings['logo_url']) : ?>
                            <p>Current Logo: <img src="<?php echo esc_url($settings['logo_url']); ?>" class="scv-preview-img"></p>
                            <p><input type="checkbox" name="scv_delete_logo" value="1" class="scv-checkbox"> Delete Logo</p>
                        <?php endif; ?>
                    </td>
                </tr>
                <tr>
                    <th><label for="scv_signature">Signature Upload</label></th>
                    <td>
                        <input type="file" name="scv_signature" id="scv_signature" accept="image/png,image/jpeg" class="scv-file-input">
                        <?php if ($settings['signature_url']) : ?>
                            <p>Current Signature: <img src="<?php echo esc_url($settings['signature_url']); ?>" class="scv-preview-img"></p>
                            <p><input type="checkbox" name="scv_delete_signature" value="1" class="scv-checkbox"> Delete Signature</p>
                        <?php endif; ?>
                    </td>
                </tr>
                <tr>
                    <th><label for="scv_seal">Seal Upload</label></th>
                    <td>
                        <input type="file" name="scv_seal" id="scv_seal" accept="image/png,image/jpeg" class="scv-file-input">
                        <?php if ($settings['seal_url']) : ?>
                            <p>Current Seal: <img src="<?php echo esc_url($settings['seal_url']); ?>" class="scv-preview-img"></p>
                            <p><input type="checkbox" name="scv_delete_seal" value="1" class="scv-checkbox"> Delete Seal</p>
                        <?php endif; ?>
                    </td>
                </tr>
            </table>
            <p class="submit">
                <input type="submit" value="Save Changes" class="button button-primary scv-submit-btn">
            </p>
        </form>
    </div>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const cards = document.querySelectorAll('.scv-template-card');
            const hiddenInput = document.getElementById('scv_background_template');
            const preview = document.getElementById('background_preview');

            cards.forEach(card => {
                card.addEventListener('click', function() {
                    cards.forEach(c => c.classList.remove('selected'));
                    this.classList.add('selected');
                    const template = this.getAttribute('data-template');
                    hiddenInput.value = template;
                    preview.src = '<?php echo plugin_dir_url(__FILE__) . '../../images/'; ?>' + template;
                });
            });
        });
    </script>
    <style>
        .scv-template-cards {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }
        .scv-template-card {
            width: 150px;
            padding: 10px;
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
            text-align: center;
            cursor: pointer;
            transition: all 0.3s ease;
        }
        .scv-template-card:hover {
            box-shadow: 0 6px 15px rgba(0, 0, 0, 0.2);
            transform: translateY(-5px);
        }
        .scv-template-card.selected {
            border: 3px solid #0073aa;
            box-shadow: 0 6px 15px rgba(0, 115, 170, 0.3);
        }
        .scv-template-card img {
            max-width: 100%;
            height: auto;
            border-radius: 4px;
        }
        .scv-template-card p {
            margin: 5px 0 0;
            font-size: 14px;
            color: #333;
        }
        .scv-divider {
            border: 0;
            height: 1px;
            background: #0073aa;
            margin: 10px 0;
            opacity: 0.5;
        }
        .scv-preview-img {
            max-width: 400px;
            height: auto;
            border: 1px solid #ddd;
            padding: 5px;
            background: #fff;
            border-radius: 4px;
            margin-top: 10px;
        }
        .scv-checkbox {
            margin-right: 10px;
        }
    </style>
    <?php
}
?>