<?php
if (!defined('ABSPATH')) {
    exit;
}

function scv_validate_license_key($license_key) {
    $domain = sanitize_text_field($_SERVER['HTTP_HOST']);
    $response = wp_remote_post('https://onlinegeldverdienen.digital/wp-json/license-manager/v1/validate', [
        'body' => [
            'license_key' => $license_key,
            'domain' => $domain
        ],
        'timeout' => 15,
    ]);

    if (is_wp_error($response)) {
        return ['status' => 'error', 'message' => 'Cannot connect to license server'];
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    return $data ?: ['status' => 'error', 'message' => 'Invalid response from server'];
}

function scv_check_license() {
    $license_key = get_option('scv_license_key', '');
    if (empty($license_key)) {
        return false;
    }

    $result = scv_validate_license_key($license_key);
    update_option('scv_license_status', $result['status']);
    update_option('scv_license_message', $result['message']);

    return $result['status'] === 'valid';
}

function scv_show_license_notice() {
    $status = get_option('scv_license_status', '');
    $message = get_option('scv_license_message', 'Please enter a valid license key.');
    if ($status !== 'valid') {
        echo '<div class="error"><p><strong>Student Certificate Verification:</strong> ' . esc_html($message) . '</p></div>';
    }
}
add_action('admin_notices', 'scv_show_license_notice');
