<?php
if (!defined('ABSPATH')) {
    exit;
}

// Register Student Post Type
function scv_register_student_post_type() {
    $args = array(
        'labels' => array(
            'name' => 'Students',
            'singular_name' => 'Student',
            'menu_name' => 'Student Records',
            'add_new' => 'Add Student',
            'add_new_item' => 'Add New Student',
            'edit_item' => 'Edit Student',
            'enter_title_here' => 'Enter Student Name Here',
        ),
        'public' => false,
        'show_ui' => true,
        'show_in_menu' => true,
        'menu_position' => 5,
        'menu_icon' => 'dashicons-welcome-learn-more',
        'supports' => array('title'),
    );
    register_post_type('student_certificate', $args);
}
add_action('init', 'scv_register_student_post_type');

function scv_custom_enter_title_here($title, $post) {
    if ($post->post_type === 'student_certificate') {
        return 'Enter Student Name Here';
    }
    return $title;
}
add_filter('enter_title_here', 'scv_custom_enter_title_here', 10, 2);

// Cache Customization Settings
function scv_get_customization_settings() {
    $cache_key = 'scv_customization_settings';
    $settings = wp_cache_get($cache_key);
    if (false === $settings) {
        $settings = array(
            'reg_prefix' => get_option('scv_reg_prefix', 'Regd. No.'),
            'academy_name' => get_option('scv_academy_name', 'Creative Deep Academy'),
            'academy_size' => get_option('scv_academy_size', 20),
            'academy_color' => get_option('scv_academy_color', '000000'),
            'certification_line1' => get_option('scv_certification_line1', 'Registered under MSEMI of Govt'),
            'certification_line1_color' => get_option('scv_certification_line1_color', '000000'),
            'certification_line2' => get_option('scv_certification_line2', 'GST registered under the act of 22'),
            'certification_line2_color' => get_option('scv_certification_line2_color', '000000'),
            'certificate_title' => get_option('scv_certificate_title', 'Certificate of Completion'),
            'title_size' => get_option('scv_title_size', 20),
            'title_color' => get_option('scv_title_color', '000000'),
            'certification_text' => get_option('scv_certification_text', 'This is to certify that [student_name] [father_name] has completed the course [course_name] in [year_of_passing] with [percentage] from [academy_name] and is awarded this certificate.'),
            'certification_size' => get_option('scv_certification_size', 12),
            'certification_color' => get_option('scv_certification_color', '000000'),
            'additional_info' => get_option('scv_additional_info', 'For more details or Diploma Verification: www.yourschool.com'),
            'additional_info_color' => get_option('scv_additional_info_color', '000000'),
            'font_choice' => get_option('scv_font_choice', 'Arial'),
            'background_template' => get_option('scv_background_template', scv_get_default_background_template()),
            'logo_path' => get_option('scv_logo_path', ''),
            'logo_url' => get_option('scv_logo_url', ''),
            'signature_path' => get_option('scv_signature_path', ''),
            'signature_url' => get_option('scv_signature_url', ''),
            'seal_path' => get_option('scv_seal_path', ''),
            'seal_url' => get_option('scv_seal_url', ''),
        );
        wp_cache_set($cache_key, $settings, '', 3600);
    }
    return $settings;
}

// Function to get available background templates dynamically
function scv_get_background_templates() {
    $images_dir = SCV_PLUGIN_DIR . 'images/';
    $templates = glob($images_dir . '*.png'); // Match all .png files
    if (empty($templates)) {
        error_log('No background templates found in ' . $images_dir);
        return ['new_template1.png' => 'New Template 1']; // Fallback with a default name
    }
    $template_list = [];
    foreach ($templates as $template) {
        $filename = basename($template);
        $label = ucwords(str_replace('_', ' ', preg_replace('/\.png$/', '', $filename)));
        $template_list[$filename] = $label;
    }
    return $template_list;
}

// Function to determine the default background template
function scv_get_default_background_template() {
    $templates = scv_get_background_templates();
    $saved_template = get_option('scv_background_template', '');
    if ($saved_template && array_key_exists($saved_template, $templates)) {
        return $saved_template;
    }
    return key(array_slice($templates, 0, 1, true)); // Return the first available template
}

// Add custom columns to Student Records list
function scv_add_student_columns($columns) {
    $new_columns = array();
    foreach ($columns as $key => $value) {
        if ($key === 'title') {
            $new_columns['student_info'] = 'Student Info';
        } else {
            $new_columns[$key] = $value;
        }
    }
    return $new_columns;
}
add_filter('manage_student_certificate_posts_columns', 'scv_add_student_columns');

// Display custom column data
function scv_display_student_columns($column, $post_id) {
    if ($column === 'student_info') {
        $student_name = get_the_title($post_id);
        $certificate_number = get_post_meta($post_id, 'certificate_number', true);
        echo esc_html($student_name);
        if ($certificate_number) {
            echo ' <span style="color: #0073aa; font-weight: bold;">(' . esc_html($certificate_number) . ')</span>';
        }
    }
}
add_action('manage_student_certificate_posts_custom_column', 'scv_display_student_columns', 10, 2);

// Make the column sortable
function scv_sortable_student_columns($columns) {
    $columns['student_info'] = 'title';
    return $columns;
}
add_filter('manage_edit-student_certificate_sortable_columns', 'scv_sortable_student_columns');

// Clear cache on plugin activation or settings update
function scv_clear_cache_on_activation() {
    wp_cache_delete('scv_customization_settings');
}
register_activation_hook(__FILE__, 'scv_clear_cache_on_activation');

// Clear cache when images might change
function scv_clear_cache_on_file_change() {
    $images_dir = SCV_PLUGIN_DIR . 'images/';
    if (is_dir($images_dir)) {
        $files = glob($images_dir . '*.png');
        $last_modified = 0;
        foreach ($files as $file) {
            $mtime = filemtime($file);
            $last_modified = max($last_modified, $mtime);
        }
        $cached_time = get_option('scv_images_last_modified', 0);
        if ($last_modified > $cached_time) {
            wp_cache_delete('scv_customization_settings');
            update_option('scv_images_last_modified', $last_modified);
        }
    }
}
add_action('admin_init', 'scv_clear_cache_on_file_change');
?>