<?php
if (!defined('ABSPATH')) {
    exit;
}

// Certificate Verification Shortcode
function scv_certificate_verification_form() {
    ob_start();
    ?>
    <style>
        .scv-container { max-width: 600px; margin: 50px auto; padding: 20px; background: #ffffff; border-radius: 10px; box-shadow: 0px 4px 15px rgba(0, 0, 0, 0.2); text-align: center; font-family: Arial, sans-serif; }
        .scv-container h3 { margin-bottom: 15px; color: #0073aa; }
        .scv-container input { width: 80%; padding: 10px; margin: 10px 0; border: 1px solid #ccc; border-radius: 5px; text-align: center; font-size: 16px; }
        .scv-container button { background: #0073aa; color: #fff; padding: 10px 20px; border: none; border-radius: 5px; cursor: pointer; font-size: 16px; transition: 0.3s; }
        .scv-container button:hover { background: #005177; }
        .scv-results { margin-top: 20px; padding: 20px; background: #f8f8f8; border-radius: 10px; box-shadow: 0px 0px 10px rgba(0, 0, 0, 0.1); text-align: left; }
        .scv-results h3 { text-align: center; color: #333; }
        .scv-results p { font-size: 16px; margin: 5px 0; color: #333; border-bottom: 1px solid #ddd; padding-bottom: 5px; }
        .scv-results p strong { color: #0073aa; }
        .scv-download-btn { display: inline-block; margin: 5px; padding: 10px 15px; background: #28a745; color: white; text-decoration: none; border-radius: 5px; font-size: 16px; text-transform: uppercase; font-weight: bold; }
        .scv-download-btn:hover { background: #218838; }
        .scv-error { color: red; margin-top: 10px; font-weight: bold; }
    </style>
    <div class="scv-container">
        <h3>Certificate Verification</h3>
        <form method="post">
            <input type="text" name="certificate_number" placeholder="Enter Certificate Number" required>
            <?php wp_nonce_field('scv_verify_action', 'scv_verify_nonce'); ?>
            <button type="submit">Verify</button>
        </form>
        <?php
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['certificate_number'])) {
            if (!isset($_POST['scv_verify_nonce']) || !wp_verify_nonce($_POST['scv_verify_nonce'], 'scv_verify_action')) {
                echo "<p class='scv-error'>❌ Security check failed. Please try again.</p>";
            } else {
                $certificate_number = sanitize_text_field($_POST['certificate_number']);
                $args = array(
                    'post_type' => 'student_certificate',
                    'posts_per_page' => 1,
                    'meta_query' => array(
                        array(
                            'key' => 'certificate_number',
                            'value' => $certificate_number,
                            'compare' => '='
                        )
                    )
                );
                $query = new WP_Query($args);
                if ($query->have_posts()) {
                    while ($query->have_posts()) {
                        $query->the_post();
                        $pdf_link = get_post_meta(get_the_ID(), 'pdf_download_link', true);
                        ?>
                        <div class="scv-results">
                            <h3>Student Certificate Details</h3>
                            <p><strong>Student Name:</strong> <?php the_title(); ?></p>
                            <p><strong>Gender:</strong> <?php echo esc_html(get_post_meta(get_the_ID(), 'gender', true) ?: 'N/A'); ?></p>
                            <p><strong>Father Name:</strong> <?php echo esc_html(get_post_meta(get_the_ID(), 'father_name', true) ?: 'N/A'); ?></p>
                            <p><strong>Course Name:</strong> <?php echo esc_html(get_post_meta(get_the_ID(), 'course_name', true) ?: 'N/A'); ?></p>
                            <p><strong>Certificate Number:</strong> <?php echo esc_html(get_post_meta(get_the_ID(), 'certificate_number', true) ?: 'N/A'); ?></p>
                            <p><strong>Percentage:</strong> <?php echo esc_html(get_post_meta(get_the_ID(), 'percentage', true) ? get_post_meta(get_the_ID(), 'percentage', true) . '%' : 'N/A'); ?></p>
                            <p><strong>Year of Passing:</strong> <?php echo esc_html(get_post_meta(get_the_ID(), 'year_of_passing', true) ?: 'N/A'); ?></p>
                            <p><strong>Academy Name:</strong> <?php echo esc_html(get_post_meta(get_the_ID(), 'academy_name', true) ?: 'N/A'); ?></p>
                            <?php if (!empty($pdf_link)) : ?>
                                <?php
                                $upload_dir = wp_upload_dir();
                                $pdf_path = str_replace($upload_dir['url'], $upload_dir['path'], $pdf_link);
                                if (file_exists($pdf_path)) : ?>
                                    <a class="scv-download-btn" href="<?php echo esc_url($pdf_link); ?>" target="_blank">View Certificate</a>
                                    <a class="scv-download-btn" href="<?php echo esc_url($pdf_link); ?>" download>Download Certificate</a>
                                <?php else : ?>
                                    <p class="scv-error">❌ PDF file not found on server.</p>
                                <?php endif; ?>
                            <?php else : ?>
                                <p class="scv-error">❌ No PDF available for download.</p>
                            <?php endif; ?>
                        </div>
                        <?php
                    }
                    wp_reset_postdata();
                } else {
                    echo "<p class='scv-error'>❌ No record found! Please check the Certificate Number.</p>";
                }
            }
        }
        ?>
    </div>
    <?php
    return ob_get_clean();
}
add_shortcode('verify_certificate', 'scv_certificate_verification_form');