<?php
/**
 * Plugin Name: Student Certificate Verification
 * Plugin URI: https://certificateverificationplugin.com/
 * Description: A plugin to verify student certificates online with advanced customization options.
 * Version: 2.9.1
 * Author: Rasdeep Singh
 * Author URI: https://certificateverificationplugin.com/
 * License: GPL-2.0+
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: student-certificate-verification
 * Shortcodes: [verify_certificate] - Displays a certificate verification form on the front end.
 */

if (!defined('ABSPATH')) {
    exit;
}

// Define plugin path constant
define('SCV_PLUGIN_DIR', plugin_dir_path(__FILE__));

// Load FPDF library
$fpdf_path = SCV_PLUGIN_DIR . 'lib/fpdf.php';
if (file_exists($fpdf_path)) {
    require_once $fpdf_path;
} else {
    error_log('FPDF library not found at: ' . $fpdf_path);
    add_action('admin_notices', function() {
        echo '<div class="error"><p><strong>Student Certificate Verification:</strong> FPDF library is missing. Please ensure lib/fpdf.php exists in the plugin directory.</p></div>';
    });
    return;
}

// Load core functionality
require_once SCV_PLUGIN_DIR . 'includes/core/post-type.php';
require_once SCV_PLUGIN_DIR . 'includes/core/license.php'; // License file included here

// Load admin functionality
require_once SCV_PLUGIN_DIR . 'includes/admin/admin-menus.php';
require_once SCV_PLUGIN_DIR . 'includes/admin/student-meta.php';
require_once SCV_PLUGIN_DIR . 'includes/admin/bulk-upload.php';
require_once SCV_PLUGIN_DIR . 'includes/admin/customization.php';

// Load frontend functionality
require_once SCV_PLUGIN_DIR . 'includes/frontend/shortcode.php';

// Enqueue admin styles and scripts
function scv_enqueue_admin_assets($hook) {
    $screen = get_current_screen();
    if ($screen && ($screen->post_type === 'student_certificate' || 
        $screen->id === 'student_certificate_page_scv-customization' || 
        $screen->id === 'student_certificate_page_scv-bulk-upload')) {
        // Always enqueue styles and scripts for admin pages
        wp_enqueue_style('scv-admin-styles', plugin_dir_url(__FILE__) . 'assets/css/admin-styles.css', array(), '2.9.1');
        wp_enqueue_script('scv-admin-scripts', plugin_dir_url(__FILE__) . 'assets/js/admin-scripts.js', array('jquery'), '2.9.1', true);
        wp_localize_script('scv-admin-scripts', 'scv_vars', [
            'plugin_url' => plugin_dir_url(__FILE__)
        ]);
    }
}
add_action('admin_enqueue_scripts', 'scv_enqueue_admin_assets');

function scv_plugin_action_links($links) {
    $go_pro_link = '<a href="https://certificateverificationplugin.com/" target="_blank" style="color: #d64e07; font-weight: bold;">Go Pro</a>';
    array_push($links, $go_pro_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'scv_plugin_action_links');

// Disable features if license is invalid
function scv_disable_on_invalid_license() {
    if (!function_exists('scv_check_license') || !scv_check_license()) {
        // Only disable save_post action, keep shortcode and CSS active
        // The 5-student limit is handled in scv_limit_free_version
    }
}
add_action('init', 'scv_disable_on_invalid_license');

// Enable debugging (optional, for finding errors)
if (!defined('WP_DEBUG')) {
    define('WP_DEBUG', true);
}
if (!defined('WP_DEBUG_LOG')) {
    define('WP_DEBUG_LOG', true);
}
if (!defined('WP_DEBUG_DISPLAY')) {
    define('WP_DEBUG_DISPLAY', false);
}
?>